import { useEffect } from 'react';
import { createMachine, assign } from 'xstate';
import { useMachine } from '@xstate/react';

function isEqual(array1, array2) {
  return JSON.stringify(array1) === JSON.stringify(array2);
}
function takeRight(array, n) {
  if (n < 1) return [];
  return array.slice(-1 * n);
}

var initialCheatCodeMachineContext = {
  typedKeys: []
};

function createCheatCodeMachine(cheatCodeKeys) {
  return createMachine({
    id: 'cheatCode',
    initial: 'disabled',
    context: initialCheatCodeMachineContext,
    states: {
      disabled: {
        initial: 'idle',
        states: {
          idle: {
            always: [{
              target: '#cheatCode.enabled',
              cond: 'cheatCodeEntered',
              actions: 'reset'
            }],
            on: {
              keydown: {
                target: 'recording',
                actions: 'record'
              }
            }
          },
          recording: {
            always: [{
              target: '#cheatCode.enabled',
              cond: 'cheatCodeEntered',
              actions: 'reset'
            }],
            on: {
              keydown: {
                target: 'recording',
                actions: 'record'
              }
            },
            after: {
              DONE_TYPING: {
                target: 'idle',
                actions: 'reset'
              }
            }
          }
        }
      },
      enabled: {
        initial: 'idle',
        states: {
          idle: {
            always: [{
              target: '#cheatCode.disabled',
              cond: 'cheatCodeEntered',
              actions: 'reset'
            }],
            on: {
              keydown: {
                target: 'recording',
                actions: 'record'
              }
            }
          },
          recording: {
            always: [{
              target: '#cheatCode.disabled',
              cond: 'cheatCodeEntered',
              actions: 'reset'
            }],
            on: {
              keydown: {
                target: 'recording',
                actions: 'record'
              }
            },
            after: {
              DONE_TYPING: {
                target: 'idle',
                actions: 'reset'
              }
            }
          }
        }
      }
    }
  }, {
    delays: {
      DONE_TYPING: 2000
    },
    actions: {
      reset: assign(initialCheatCodeMachineContext),
      record: assign({
        typedKeys: function typedKeys(context, event) {
          return [].concat(context.typedKeys, [event.key]);
        }
      })
    },
    guards: {
      cheatCodeEntered: function cheatCodeEntered(context) {
        return isEqual(takeRight(context.typedKeys, cheatCodeKeys.length), cheatCodeKeys);
      }
    }
  });
}

function useCheatCode(cheatCodeKeys) {
  var _useMachine = useMachine(createCheatCodeMachine(cheatCodeKeys)),
      current = _useMachine[0],
      send = _useMachine[1];

  useEffect(function () {
    window.addEventListener('keydown', send);
    return function () {
      window.removeEventListener('keydown', send);
    };
  }, [send]);
  return current.matches('enabled');
}
var useSecretCode = useCheatCode;

export { useCheatCode, useSecretCode };
//# sourceMappingURL=use-secret-code.esm.js.map
